<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh">
<context>
    <name>CompletingEdit</name>
    <message>
        <source>Jump to PDF</source>
        <translation>跳至 PDF 文件</translation>
    </message>
    <message>
        <source>No suggestions</source>
        <translation>没有可用的建议</translation>
    </message>
    <message>
        <source>Ignore word</source>
        <translation>忽略单词</translation>
    </message>
</context>
<context>
    <name>ConfirmDelete</name>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Unable to delete</source>
        <translation>无法删除</translation>
    </message>
    <message>
        <source>Some of the auxiliary files could not be removed. Perhaps you don&apos;t have permission to delete them.</source>
        <translation>有些辅助文件无法移除。可能因为您没有足够的权限删除它们。</translation>
    </message>
    <message>
        <source>Confirm file deletion</source>
        <translation>确认要删除的文件</translation>
    </message>
    <message>
        <source>Auxiliary files to be deleted:</source>
        <translation>要删除的辅助文件：</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>选择所有</translation>
    </message>
    <message>
        <source>Select None</source>
        <translation>清除选择</translation>
    </message>
    <message>
        <source>Toggle</source>
        <translation>切换选择状态</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Find</source>
        <translation>查找</translation>
    </message>
    <message>
        <source>Find:</source>
        <translation>查找：</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>循环查找 (&amp;W)</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>向后查找 (&amp;b)</translation>
    </message>
    <message>
        <source>Search within &amp;selection</source>
        <translation>在所选区域中查找 (&amp;s)</translation>
    </message>
    <message>
        <source>Find &amp;all occurrences</source>
        <translation>查找所有匹配字串 (&amp;a)</translation>
    </message>
    <message>
        <source>Search all &amp;open files</source>
        <translation>搜索所有已打开文件 (&amp;o)</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>区分大小写 (&amp;C)</translation>
    </message>
    <message>
        <source>W&amp;hole words</source>
        <translation>全字匹配 (&amp;h)</translation>
    </message>
    <message>
        <source>&amp;Regular expression</source>
        <translation>使用正则表达式 (&amp;R)</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>最近没有搜索字串</translation>
    </message>
    <message>
        <source>(invalid)</source>
        <translation>(无效)</translation>
    </message>
</context>
<context>
    <name>HardWrapDialog</name>
    <message>
        <source>Hard Wrap</source>
        <translation>硬换行</translation>
    </message>
    <message>
        <source>Wrap lines to:</source>
        <translation>折行至：</translation>
    </message>
    <message>
        <source>Current window size</source>
        <translation>当前窗口大小</translation>
    </message>
    <message>
        <source>Line length:</source>
        <translation>行宽：</translation>
    </message>
    <message>
        <source>Re-wrap paragraphs</source>
        <translation>重新对段落执行换行操作</translation>
    </message>
    <message>
        <source>Unwrap</source>
        <translation>取消换行（合并行）</translation>
    </message>
</context>
<context>
    <name>PDFDocument</name>
    <message>
        <source>Open Recent</source>
        <translation>打开最近的文件</translation>
    </message>
    <message>
        <source>Failed to load file &quot;%1&quot;; perhaps it is not a valid PDF document.</source>
        <translation>无法加载文件“%1”；可能它不是一个有效的 PDF 文档。</translation>
    </message>
    <message>
        <source>No SyncTeX data available</source>
        <translation>无法得到 SyncTeX 数据</translation>
    </message>
    <message>
        <source>SyncTeX: &quot;%1&quot;</source>
        <translation>SyncTeX：“%1”</translation>
    </message>
    <message>
        <source>%1[*] - %2</source>
        <translation>%1[*] - %2</translation>
    </message>
    <message>
        <source>page %1 of %2</source>
        <translation>页 %1/%2</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
    <message>
        <source>untitled.pdf[*]</source>
        <translation>未命名.pdf[*]</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <source>File</source>
        <translation>文件</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>View</source>
        <translation>视图</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>窗口</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>显示</translation>
    </message>
    <message>
        <source>Typeset</source>
        <translation>排版</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>工具栏</translation>
    </message>
    <message>
        <source>About TeXworks...</source>
        <translation>关于 TeXworks...</translation>
    </message>
    <message>
        <source>First Page</source>
        <translation>第一页</translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>上一页</translation>
    </message>
    <message>
        <source>Ctrl+PgUp</source>
        <comment>shortcut key name, do not translate</comment>
        <translation></translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>下一页</translation>
    </message>
    <message>
        <source>Ctrl+PgDown</source>
        <comment>shortcut key name, do not translate</comment>
        <translation></translation>
    </message>
    <message>
        <source>Last Page</source>
        <translation>最后一页</translation>
    </message>
    <message>
        <source>Go to Page...</source>
        <translation>跳至页码…</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation></translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>放大</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation></translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>缩小</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation></translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>适合页面</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation></translation>
    </message>
    <message>
        <source>Actual Size</source>
        <translation>实际大小</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation></translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>适合页面宽度</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation></translation>
    </message>
    <message>
        <source>New</source>
        <translation>新建</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>打开…</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>撤销</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>重做</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Z</source>
        <translation></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
    <message>
        <source>Ctrl+Backspace</source>
        <translation></translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>首选项...</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>层叠</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>平铺</translation>
    </message>
    <message>
        <source>Go to Source</source>
        <translation>转到源文件</translation>
    </message>
    <message>
        <source>Ctrl+&apos;</source>
        <translation></translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>从模板新建...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Full Screen</source>
        <translation>全屏显示</translation>
    </message>
    <message>
        <source>Ctrl+Shift+F</source>
        <translation></translation>
    </message>
    <message>
        <source>Magnify</source>
        <translation>放大</translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation>滚屏</translation>
    </message>
    <message>
        <source>Select Text</source>
        <translation>选择文本</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>选择图像</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>TeXworks 主页</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>发送 Email 至邮件列表</translation>
    </message>
    <message>
        <source>Side by Side</source>
        <translation>并排</translation>
    </message>
    <message>
        <source>Place on Left</source>
        <translation>置于左侧</translation>
    </message>
    <message>
        <source>Place on Right</source>
        <translation>置于右侧</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>退出 TeXworks</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <source>Find...</source>
        <translation>查找…</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation></translation>
    </message>
    <message>
        <source>Find Again</source>
        <translation>查找下一个</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation></translation>
    </message>
    <message>
        <source>Typeset</source>
        <comment>menu title</comment>
        <translation>排版</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <comment>action</comment>
        <translation></translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>脚本</translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation>管理脚本</translation>
    </message>
    <message>
        <source>Show Scripts Folder</source>
        <translation>显示脚本文件夹</translation>
    </message>
    <message>
        <source>Abort typesetting</source>
        <translation>中止排版</translation>
    </message>
    <message>
        <source>Scripting TeXworks</source>
        <translation>TeXworks脚本</translation>
    </message>
    <message>
        <source>Reload Script List</source>
        <translation>重载脚本列表</translation>
    </message>
    <message>
        <source>About Scripts...</source>
        <translation>关于脚本...</translation>
    </message>
    <message>
        <source>Print Pdf...</source>
        <translation>打印 Pdf...</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation></translation>
    </message>
    <message>
        <source>Unfortunately, this version of %1 is unable to print Pdf documents due to various technical reasons.
</source>
        <translation>很不幸，由于各种技术原因本版本 %1 无法打印 PDF 文档。
</translation>
    </message>
    <message>
        <source>Do you want to open the file in the default viewer for printing instead?</source>
        <translation>是否使用默认 PDF 阅读器打开文件以便于打印？</translation>
    </message>
    <message>
        <source> (remember to close it again to avoid access problems)</source>
        <translation>（记住关闭文档以避免文件访问问题）</translation>
    </message>
    <message>
        <source>Settings and Resources...</source>
        <translation>配置与资源...</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>清除近期文件</translation>
    </message>
    <message>
        <source>Error initializing SyncTeX</source>
        <translation>SyncTeX 初始化错误</translation>
    </message>
    <message>
        <source>Go to previous view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+Left</source>
        <translation type="unfinished">Alt+Left</translation>
    </message>
    <message>
        <source>Single Page</source>
        <translation>单页</translation>
    </message>
    <message>
        <source>Single Page Continuous</source>
        <translation>连续单页</translation>
    </message>
    <message>
        <source>Two Pages Continuous</source>
        <translation>连续双页</translation>
    </message>
    <message>
        <source>Jump to Source</source>
        <translation>跳至源文件</translation>
    </message>
    <message>
        <source>Go to Page</source>
        <translation type="unfinished">跳至页码</translation>
    </message>
    <message>
        <source>Page number:</source>
        <translation>页码：</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You are in the process of opening the URL %1. Opening unknown or untrusted web adresses can be a security risk.
Do you want to continue?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom level:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PDFFindDialog</name>
    <message>
        <source>Find</source>
        <translation>查找</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>最近没有搜索字串</translation>
    </message>
    <message>
        <source>Find in PDF</source>
        <translation>在 PDF 文件中查找</translation>
    </message>
    <message>
        <source>Find:</source>
        <translation>查找：</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>循环查找 (&amp;W)</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>向后查找 (&amp;b)</translation>
    </message>
    <message>
        <source>Find &amp;all occurrences</source>
        <translation>查找所有出现字串 (&amp;a)</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>区分大小写 (&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Sync to source</source>
        <translation>同步到源文件 (&amp;S)</translation>
    </message>
</context>
<context>
    <name>PrefsDialog</name>
    <message>
        <source>Choose Directory</source>
        <translation>选择目录</translation>
    </message>
    <message>
        <source>New Tool</source>
        <translation>新建工具</translation>
    </message>
    <message>
        <source>System default [%1]</source>
        <translation>系统默认［%1］</translation>
    </message>
    <message>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <source>TeXworks Preferences</source>
        <translation>TeXworks 首选项</translation>
    </message>
    <message>
        <source>General</source>
        <translation>常规</translation>
    </message>
    <message>
        <source>Small icons</source>
        <translation>小图标</translation>
    </message>
    <message>
        <source>Medium icons</source>
        <translation>中等图标</translation>
    </message>
    <message>
        <source>Large icons</source>
        <translation>大图标</translation>
    </message>
    <message>
        <source>Show text as well as icons</source>
        <translation>显示图标和文字</translation>
    </message>
    <message>
        <source>When launched, show</source>
        <translation>当加载时，显示</translation>
    </message>
    <message>
        <source>New blank document</source>
        <translation>新建空文档</translation>
    </message>
    <message>
        <source>Template selection dialog</source>
        <translation>模板选择对话框</translation>
    </message>
    <message>
        <source>File Open dialog</source>
        <translation>文件打开对话框</translation>
    </message>
    <message>
        <source>Editor</source>
        <translation>编辑器</translation>
    </message>
    <message>
        <source>Editor defaults</source>
        <translation>编辑器默认配置</translation>
    </message>
    <message>
        <source> pt</source>
        <translation>磅</translation>
    </message>
    <message>
        <source>Tab width:</source>
        <translation>Tab 宽度：</translation>
    </message>
    <message>
        <source>Wrap lines</source>
        <translation>自动换行</translation>
    </message>
    <message>
        <source>Syntax coloring:</source>
        <translation>语法高亮：</translation>
    </message>
    <message>
        <source>Auto-Indent mode:</source>
        <translation>自动缩进模式：</translation>
    </message>
    <message>
        <source>Spell-check language:</source>
        <translation>拼写检查语言：</translation>
    </message>
    <message>
        <source>Encoding:</source>
        <translation>编码：</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>预览</translation>
    </message>
    <message>
        <source>Default scaling</source>
        <translation>默认缩放比例</translation>
    </message>
    <message>
        <source>Actual size</source>
        <translation>实际大小</translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>适合页面宽度</translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>适合页面</translation>
    </message>
    <message>
        <source>Fixed scale:</source>
        <translation>固定缩放比例：</translation>
    </message>
    <message>
        <source> %</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Magnifying glass</source>
        <translation>放大镜</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>小</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>中等</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>大</translation>
    </message>
    <message>
        <source>Circular magnifier</source>
        <translation>圆形放大镜</translation>
    </message>
    <message>
        <source>Screen resolution:</source>
        <translation>屏幕分辨率：</translation>
    </message>
    <message>
        <source> dpi</source>
        <translation type="obsolete">dpi</translation>
    </message>
    <message>
        <source>Typesetting</source>
        <translation>排版</translation>
    </message>
    <message>
        <source>Paths for TeX and related programs</source>
        <translation>TeX 及相关程序路径</translation>
    </message>
    <message>
        <source>Processing tools</source>
        <translation>处理工具</translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation>编辑…</translation>
    </message>
    <message>
        <source>Default:</source>
        <translation>默认：</translation>
    </message>
    <message>
        <source>Line numbers</source>
        <translation>行号</translation>
    </message>
    <message>
        <source>Global editor options</source>
        <translation>全局编辑器选项</translation>
    </message>
    <message>
        <source>Highlight current line</source>
        <translation>高亮显示当前行</translation>
    </message>
    <message>
        <source>Smart Quotes mode:</source>
        <translation>智能引号模式：</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>脚本</translation>
    </message>
    <message>
        <source>Enable QtScript debugger</source>
        <translation>启用 QtScript 调试器</translation>
    </message>
    <message>
        <source>Allow scripts to run system commands</source>
        <translation>允许脚本运行系统命令</translation>
    </message>
    <message>
        <source> px</source>
        <translation>像素</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>安全性</translation>
    </message>
    <message>
        <source>Allow scripts to write files</source>
        <translation>允许脚本写文件</translation>
    </message>
    <message>
        <source>Enable plug-in scripting languages (may circumvent other restrictions on script behavior)</source>
        <translation>启用插件脚本语言（可以避开对脚本行为的其它限制）</translation>
    </message>
    <message>
        <source>Debugging</source>
        <translation>调试</translation>
    </message>
    <message>
        <source>Allow scripts to read all files (script and document files are always readable)</source>
        <translation>允许脚本读取所有文件（脚本和文档文件始终可读）</translation>
    </message>
    <message>
        <source>Never</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translation>排版后始终显示输出面板</translation>
    </message>
    <message>
        <source>Automatically</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translation>自动</translation>
    </message>
    <message>
        <source>On success</source>
        <extracomment>&quot;Hide console output&quot; mode</extracomment>
        <translation>排版成功后隐藏输出面板</translation>
    </message>
    <message>
        <source>&lt;em&gt;Note:&lt;/em&gt; These are default settings. Changes to them will not affect windows that are already open. Use the respective items in the &amp;quot;Format&amp;quot; menu to achieve that.</source>
        <translation>注：以上为默认设置。改变它们不会影响现有已打开窗口。可以通过修改“格式”菜单中的对应菜单项来改变现有窗口的设定。</translation>
    </message>
    <message>
        <source>Enable autocompletion</source>
        <translation>启用自动补全</translation>
    </message>
    <message>
        <source>Hide console output:</source>
        <translation>隐藏控制台输出：</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;strong&gt;Never:&lt;/strong&gt; Never hide the console output panel after typesetting.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;Automatically:&lt;/strong&gt; Hide the console output panel after successful typesetting, but only if it was hidden before.&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;On Success:&lt;/strong&gt; Hide the console output panel after successful typesetting, regardless of its previous state.&lt;/p&gt;
</source>
        <translation>&lt;p&gt;&lt;strong&gt;始终隐藏：&lt;/strong&gt;排版后始终隐藏控制台输出面板。&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;自动：&lt;/strong&gt;排版完成后控制台输出面板还原回之前状态&lt;/p&gt;
&lt;p&gt;&lt;strong&gt;排版完成后隐藏：&lt;/strong&gt;排版完成后始终隐藏控制台输出面板。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>图形界面设置</translation>
    </message>
    <message>
        <source>Locale:</source>
        <translation>区域设置（本地化）：</translation>
    </message>
    <message>
        <source>Toolbar buttons:</source>
        <translation>工具栏图标</translation>
    </message>
    <message>
        <source>Open corresponding PDF preview with TeX files</source>
        <translation>打开 TeX 文件对应的PDF预览</translation>
    </message>
    <message>
        <source>Page mode:</source>
        <translation>页面模式：</translation>
    </message>
    <message>
        <source>Single Page</source>
        <translation>单页</translation>
    </message>
    <message>
        <source>Single Page Continuous</source>
        <translation>连续单页</translation>
    </message>
    <message>
        <source>Two Page Continuous</source>
        <translation>连续双页</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>TeX documents (*.tex)</source>
        <translation>TeX 文档 (*.tex)</translation>
    </message>
    <message>
        <source>LaTeX documents (*.ltx)</source>
        <translation>LaTeX 文档 (*.ltx)</translation>
    </message>
    <message>
        <source>BibTeX databases (*.bib)</source>
        <translation>BibTeX 数据库 (*.bib)</translation>
    </message>
    <message>
        <source>Style files (*.sty)</source>
        <translation>宏包文件 (*.sty)</translation>
    </message>
    <message>
        <source>Class files (*.cls)</source>
        <translation>文档类文件 (*.cls)</translation>
    </message>
    <message>
        <source>Documented macros (*.dtx)</source>
        <translation>文档化 宏源文件 (*.dtx)</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation>文本文件 (*.txt)</translation>
    </message>
    <message>
        <source>PDF documents (*.pdf)</source>
        <translation>PDF 文档 (*.pdf)</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>所有文件</translation>
    </message>
    <message>
        <source>Log files (*.log *.blg)</source>
        <translation>日志文件 (*.log *.blg)</translation>
    </message>
    <message>
        <source>Auxiliary files (*.aux *.toc *.lot *.lof *.nav *.out *.snm *.ind *.idx *.bbl *.brf)</source>
        <translation>辅助文件 (*.aux *.toc *.lot *.lof *.nav *.out *.snm *.ind *.idx *.bbl *.brf)</translation>
    </message>
</context>
<context>
    <name>ReplaceDialog</name>
    <message>
        <source>Replace</source>
        <translation>替换</translation>
    </message>
    <message>
        <source>Replace All</source>
        <translation>替换所有</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>最近没有搜索字串</translation>
    </message>
    <message>
        <source>No recent replacement strings</source>
        <translation>最近没有被替换的字串</translation>
    </message>
    <message>
        <source>(invalid)</source>
        <translation>(无效)</translation>
    </message>
    <message>
        <source>Replace:</source>
        <translation>替换：</translation>
    </message>
    <message>
        <source>With:</source>
        <translation>使用：</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>循环查找 (&amp;W)</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>向后查找 (&amp;b)</translation>
    </message>
    <message>
        <source>Replace within &amp;selection</source>
        <translation>在选择区域中替换 (&amp;s)</translation>
    </message>
    <message>
        <source>Replace in all &amp;open files</source>
        <translation>在所有已打开文件中替换 (&amp;o)</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>区分大小写 (&amp;C)</translation>
    </message>
    <message>
        <source>W&amp;hole words</source>
        <translation>全字匹配 (&amp;h)</translation>
    </message>
    <message>
        <source>&amp;Regular expression</source>
        <translation>使用正则表达式 (&amp;R)</translation>
    </message>
</context>
<context>
    <name>ResourcesDialog</name>
    <message>
        <source>TeXworks Settings and Resources</source>
        <translation>TeXworks 配置与资源</translation>
    </message>
    <message>
        <source>Storage Locations</source>
        <translation>存储位置</translation>
    </message>
    <message>
        <source>Settings:</source>
        <translation>配置：</translation>
    </message>
    <message>
        <source>Resources:</source>
        <translation>资源：</translation>
    </message>
    <message>
        <source>Registry (%1)</source>
        <translation>注册表（%1）</translation>
    </message>
</context>
<context>
    <name>ScreenCalibrationWidget</name>
    <message>
        <source>Drag the ruler or change the value to match real world lengths.
Common paper sizes are marked as well (you may need to resize the dialog window to see them).
Use the context menu to change the units.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> dpi</source>
        <extracomment>dots per inch</extracomment>
        <translation type="unfinished">dpi</translation>
    </message>
    <message>
        <source>DIN A4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Letter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cm</source>
        <extracomment>this refers to the length unit of centimeters</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>in</source>
        <extracomment>this refers to the length unit of inches</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScriptManager</name>
    <message>
        <source>Manage Scripts</source>
        <translation>管理脚本</translation>
    </message>
    <message>
        <source>Standalone Scripts</source>
        <translation>独立脚本</translation>
    </message>
    <message>
        <source>Hook Scripts</source>
        <translation>钩子脚本</translation>
    </message>
    <message>
        <source>Name: </source>
        <translation>名称：</translation>
    </message>
    <message>
        <source>Context: </source>
        <translation>上下文：</translation>
    </message>
    <message>
        <source>Description: </source>
        <translation>描诉：</translation>
    </message>
    <message>
        <source>Author: </source>
        <translation>作者：</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation>版本：</translation>
    </message>
    <message>
        <source>Shortcut: </source>
        <translation>快捷键：</translation>
    </message>
    <message>
        <source>File: </source>
        <translation>文件：</translation>
    </message>
    <message>
        <source>Language: </source>
        <translation>语言：</translation>
    </message>
    <message>
        <source>Hook: </source>
        <translation>钩子：</translation>
    </message>
</context>
<context>
    <name>SearchResults</name>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>File</source>
        <translation>文件</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>行</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>开始</translation>
    </message>
    <message>
        <source>End</source>
        <translation>结束</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>文本</translation>
    </message>
    <message>
        <source>Search Results</source>
        <translation>搜索结果</translation>
    </message>
    <message>
        <source>Search Results - %1 (%2 found)</source>
        <translation>搜索结果 — %1（发现了 %2）</translation>
    </message>
</context>
<context>
    <name>TWApp</name>
    <message>
        <source>File</source>
        <translation>文件</translation>
    </message>
    <message>
        <source>New</source>
        <translation>新建</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>从模板新建...</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>首选项...</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>打开…</translation>
    </message>
    <message>
        <source>Open Recent</source>
        <translation>打开近期使用的文件</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <source>About </source>
        <translation>关于</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>TeXworks 主页</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>发送 Email 至邮件列表</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 is a simple environment for editing, typesetting, and previewing TeX documents.&lt;/p&gt;</source>
        <translation>&lt;p&gt;%1 是一个用于编辑、排版和预览 TeX 文档的简洁集成环境。&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://poppler.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt; PDF rendering library by Kristian H&amp;#xF8;gsberg, Albert Astals Cid and others.</source>
        <translation>&lt;br&gt;&lt;a href=&quot;http://poppler.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt; PDF 渲染库由 Kristian H&amp;#xF8;gsberg, Albert Astals Cid 及其他人开发。</translation>
    </message>
    <message>
        <source>&lt;br&gt;Concept and resources from &lt;a href=&quot;http://www.uoregon.edu/~koch/texshop/&quot;&gt;TeXShop&lt;/a&gt; by Richard Koch.</source>
        <translation>&lt;br&gt;构想和实现方法来源于 Richard Koch 开发的 &lt;a href=&quot;http://www.uoregon.edu/~koch/texshop/&quot;&gt;TeXShop&lt;/a&gt; 。</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://itexmac.sourceforge.net/SyncTeX.html&quot;&gt;SyncTeX&lt;/a&gt; technology by J&amp;#xE9;r&amp;#xF4;me Laurens.</source>
        <translation>&lt;br&gt;&lt;a href=&quot;http://itexmac.sourceforge.net/SyncTeX.html&quot;&gt;SyncTeX&lt;/a&gt; 同步技术由 J&amp;#xE9;r&amp;#xF4;me Laurens 开发。</translation>
    </message>
    <message>
        <source>&lt;br&gt;Some icons used are from the &lt;a href=&quot;http://tango.freedesktop.org/&quot;&gt;Tango Desktop Project&lt;/a&gt;.</source>
        <translation>&lt;br&gt;使用的一些图标来源于&lt;a href=&quot;http://tango.freedesktop.org/&quot;&gt;Tango 桌面项目&lt;/a&gt;。</translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 translation kindly contributed by %2.</source>
        <translation>&lt;p&gt;%1 翻译由 %2 贡献。</translation>
    </message>
    <message>
        <source>[language name]</source>
        <translation>简体中文 (Simplified Chinese)</translation>
    </message>
    <message>
        <source>[translator&apos;s name/email]</source>
        <translation>&lt;a href=&quot;mailto:crickzhang1@gmail.com&quot;&gt;Yinhe Zhang&lt;/a&gt; 和 &lt;a href=&quot;mailto:073plan@gmail.com&quot;&gt;Boyuan Yang&lt;/a&gt;</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>关于 %1</translation>
    </message>
    <message>
        <source>Unable to access &quot;%1&quot;; perhaps your browser or mail application is not properly configured?</source>
        <translation>无法访问“%1”；或许您的浏览器或邮件客户端程序没有设置正确？</translation>
    </message>
    <message>
        <source>Unable to create window</source>
        <translation>无法创建窗口</translation>
    </message>
    <message>
        <source>Something is badly wrong; %1 was unable to create a document window. The application will now quit.</source>
        <translation>有什么地方出错了；%1 无法创建文档窗口。程序现在将会退出。</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>打开文件</translation>
    </message>
    <message>
        <source>No default binary directory found</source>
        <translation>没有找到默认的可执行程序（bin）目录</translation>
    </message>
    <message>
        <source>None of the predefined directories for TeX-related programs could be found.&lt;p&gt;&lt;small&gt;To run any processes, you will need to set the binaries directory (or directories) for your TeX distribution using the Typesetting tab of the Preferences dialog.&lt;/small&gt;</source>
        <translation>没有找到 TeX 相关程序所在的预定义目录。&lt;p&gt;&lt;small&gt;为了运行任何处理程序，您需要在＜首选项＞对话框的＜排版＞选项卡中设定 TeX 系统的二进制程序目录 (bin)。&lt;/small&gt;</translation>
    </message>
    <message>
        <source>Unable to find help file.</source>
        <translation>无法找到帮助文件。</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>保存文件</translation>
    </message>
    <message>
        <source>Permission request</source>
        <translation>请求权限</translation>
    </message>
    <message>
        <source>The script &quot;%1&quot; is trying to open the file &quot;%2&quot; without sufficient permissions. Do you want to open the file?</source>
        <translation>脚本“%1”试图打开未授权文件“%2”。您想打开此文件吗？</translation>
    </message>
    <message>
        <source>&lt;p&gt;Distributed under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl-2.0.html&quot;&gt;GNU General Public License&lt;/a&gt;, version 2 or (at your option) any later version.</source>
        <translation>在 GNU 通用公共许可证（版本2）条款下分发，或根据您的个人选择选用任一后续版本。</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>清除近期文件</translation>
    </message>
    <message>
        <source>&lt;br&gt;Version %1 (%2) [r.%3, %4]</source>
        <translation>&lt;br&gt;版本 %1 (%2) [r.%3, %4] </translation>
    </message>
    <message>
        <source>&lt;br&gt;Version %1 (%2)</source>
        <translation>&lt;br&gt;版本 %1 (%2)</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>退出 TeXworks</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;a href=&quot;http://www.qt.io/&quot;&gt;Qt application framework&lt;/a&gt; v%1 by The Qt Company.</source>
        <translation>&lt;p&gt;&lt;a href=&quot;http://www.qt.io/&quot;&gt;Qt 应用程序框架&lt;/a&gt; v%1 由 Qt 公司提供。</translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://hunspell.github.io/&quot;&gt;Hunspell&lt;/a&gt; spell checker by L&amp;#xE1;szl&amp;#xF3; N&amp;#xE9;meth.</source>
        <translation>&lt;br&gt;&lt;a href=&quot;http://hunspell.github.io/&quot;&gt;Hunspell&lt;/a&gt; 拼写检查器由 L&amp;#xE1;szl&amp;#xF3; N&amp;#xE9;meth 提供。</translation>
    </message>
</context>
<context>
    <name>TWScriptAPI</name>
    <message>
        <source>Internal error</source>
        <translation>内部错误</translation>
    </message>
    <message>
        <source>Failed to execute system command: %1</source>
        <translation>系统命令运行失败：%1 </translation>
    </message>
    <message>
        <source>Error executing system command: %1</source>
        <translation>系统命令运行错误：%1</translation>
    </message>
    <message>
        <source>System command execution is disabled (see Preferences)</source>
        <translation>运行系统命令已被禁止（见＜首选项＞）</translation>
    </message>
    <message>
        <source>&quot;%1&quot; could not be opened.</source>
        <translation>“%1”无法打开。</translation>
    </message>
    <message>
        <source>Reading all files is disabled (see Preferences)</source>
        <translation>禁止读取所有文件（见首选项）</translation>
    </message>
    <message>
        <source>The file &quot;%1&quot; could not be opened for reading</source>
        <translation>无法打开文件“%1”以便读取内容</translation>
    </message>
</context>
<context>
    <name>TWScriptable</name>
    <message>
        <source>unknown error</source>
        <translation>未知错误</translation>
    </message>
    <message>
        <source>Script &quot;%1&quot;: %2</source>
        <translation>脚本“%1”：%2</translation>
    </message>
    <message>
        <source>Script result</source>
        <translation>脚本执行结果</translation>
    </message>
    <message>
        <source>Scripts may be used to add new commands to %1, and to extend or modify its behavior.</source>
        <translation>脚本可用于添加新的命令到 %1，以及扩展或修改程序行为。</translation>
    </message>
    <message>
        <source>For more information on creating and using scripts, see %1&lt;/p&gt;</source>
        <translation>关于创建和使用脚本的更多信息，参见 %1&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Scripting languages currently available in this copy of %1:</source>
        <translation>当前 %1 副本中支持的脚本语言：</translation>
    </message>
    <message>
        <source>About Scripts</source>
        <translation>关于脚本</translation>
    </message>
    <message>
        <source>Script error</source>
        <translation>脚本错误</translation>
    </message>
    <message>
        <source>(disabled in the preferences)</source>
        <extracomment>This string is appended to a script language name to indicate it is currently disabled</extracomment>
        <translation>（已在首选项中停用）</translation>
    </message>
</context>
<context>
    <name>TWSystemCmd</name>
    <message>
        <source>ERROR: failure code %1</source>
        <translation>错误：失败返回值为 %1</translation>
    </message>
    <message>
        <source>ERROR: exit code %1</source>
        <translation>错误：退出返回值为 %1</translation>
    </message>
</context>
<context>
    <name>TagsDock</name>
    <message>
        <source>Tags</source>
        <translation>标签</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>书签</translation>
    </message>
    <message>
        <source>Outline</source>
        <translation>大纲</translation>
    </message>
    <message>
        <source>No tags</source>
        <translation>没有标签</translation>
    </message>
</context>
<context>
    <name>TeXDocument</name>
    <message>
        <source>New document</source>
        <translation>新建文档</translation>
    </message>
    <message>
        <source>Open Recent</source>
        <translation>打开最近的文件</translation>
    </message>
    <message>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>打开文件</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>保存文件</translation>
    </message>
    <message>
        <source>The document &quot;%1&quot; has been modified.
Do you want to save your changes?</source>
        <translation>文档“%1”被修改了。
您想保存修改吗？</translation>
    </message>
    <message>
        <source>Do you want to discard all changes to the document &quot;%1&quot;, and revert to the last saved version?</source>
        <translation>是否放弃所有对文档“%1”的修改，并恢复到上一次保存的版本？</translation>
    </message>
    <message>
        <source>Revert</source>
        <translation>恢复</translation>
    </message>
    <message>
        <source>Unrecognized encoding</source>
        <translation>无法识别的编码</translation>
    </message>
    <message>
        <source>The text encoding %1 used in %2 is not supported.

It will be interpreted as %3 instead, which may result in incorrect text.</source>
        <translation>“%2”中使用的文本编码 %1 不支持。
将使用 %3 替代，可能会导致不正确的文本。</translation>
    </message>
    <message>
        <source>File changed on disk</source>
        <translation>保存文件至磁盘</translation>
    </message>
    <message>
        <source>%1 has been modified by another program.

Do you want to discard your current changes, and reload the file from disk?</source>
        <translation>%1 已被其它程序修改。
您想放弃当前所做修改并重新载入磁盘上的文件吗？</translation>
    </message>
    <message>
        <source>%1 has been modified by another program.

Do you want to proceed with saving this file, overwriting the version on disk?</source>
        <translation>%1 已被其它程序修改。
您想继续以保存本文件，并覆盖磁盘上的版本吗？</translation>
    </message>
    <message>
        <source>Document &quot;%1&quot; was not saved</source>
        <translation>文档 %1 没有保存</translation>
    </message>
    <message>
        <source>Text cannot be converted</source>
        <translation>无法转换文本</translation>
    </message>
    <message>
        <source>This document contains characters that cannot be represented in the encoding %1.

If you proceed, they will be replaced with default codes. Alternatively, you may wish to use a different encoding (such as UTF-8) to avoid loss of data.</source>
        <translation>此文档包含编码 %1 无法描述的字符。
如果继续进行，将使用默认代码替换。或者，您可能希望使用另一种编码（如 UTF-8）来避免丢失数据。</translation>
    </message>
    <message>
        <source>untitled-%1.tex</source>
        <translation>未命名-%1.tex</translation>
    </message>
    <message>
        <source>%1[*] - %2</source>
        <translation></translation>
    </message>
    <message>
        <source>Line %1 of %2; col %3</source>
        <translation>行 %1/%2；列 %3</translation>
    </message>
    <message>
        <source>Go to Line</source>
        <translation>跳至行</translation>
    </message>
    <message>
        <source>Line number:</source>
        <translation>行号：</translation>
    </message>
    <message>
        <source>Invalid regular expression</source>
        <translation>无效正则表达式</translation>
    </message>
    <message>
        <source>Not found</source>
        <translation>无法找到</translation>
    </message>
    <message numerus="yes">
        <source>Found %n occurrence(s)</source>
        <translation>
            <numerusform>找到 %n 处</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n occurrence(s)</source>
        <translation>
            <numerusform>%n 处</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n documents</source>
        <translation>
            <numerusform>%n 文档</numerusform>
        </translation>
    </message>
    <message>
        <source>Replaced %1 in %2</source>
        <translation>在 %2 中替换 %1</translation>
    </message>
    <message numerus="yes">
        <source>Replaced %n occurrence(s)</source>
        <translation>
            <numerusform>替换了 %n 处</numerusform>
        </translation>
    </message>
    <message>
        <source>Cannot process unsaved document</source>
        <translation>无法处理未保存文档</translation>
    </message>
    <message>
        <source>Root document %1 is not readable</source>
        <translation>根文档 %1 不可读 (无读权限)</translation>
    </message>
    <message>
        <source>%1 is not properly configured</source>
        <translation>%1 配置不恰当</translation>
    </message>
    <message>
        <source>Unable to execute %1</source>
        <translation>无法执行 %1</translation>
    </message>
    <message>
        <source>Set engine to &quot;%1&quot;</source>
        <translation>将处理引擎设为“%1”</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; not defined</source>
        <translation>处理引擎“%1”未定义</translation>
    </message>
    <message>
        <source>No files found</source>
        <translation>没有找到文件</translation>
    </message>
    <message>
        <source>No auxiliary files associated with this document at the moment.</source>
        <translation>此刻没有与当前文档关联的辅助文件。</translation>
    </message>
    <message>
        <source>untitled.tex[*]</source>
        <translation>未命名.tex[*]</translation>
    </message>
    <message>
        <source>File</source>
        <translation>文件</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>Spelling</source>
        <translation>拼写</translation>
    </message>
    <message>
        <source>Change Case</source>
        <translation>改变大小写</translation>
    </message>
    <message>
        <source>Typeset</source>
        <translation>排版</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>窗口</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>显示</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <source>Auto-indent Mode</source>
        <translation>自动缩进模式</translation>
    </message>
    <message>
        <source>Syntax Coloring</source>
        <translation>语法高亮显示</translation>
    </message>
    <message>
        <source>Smart Quotes</source>
        <translation>智能引号</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <source>Typeset Toolbar</source>
        <translation>排版工具栏</translation>
    </message>
    <message>
        <source>Edit Toolbar</source>
        <translation>编辑工具栏</translation>
    </message>
    <message>
        <source>New</source>
        <translation>新建</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>打开…</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>另存为…</translation>
    </message>
    <message>
        <source>Ctrl+Shift+S</source>
        <translation></translation>
    </message>
    <message>
        <source>Revert to Saved</source>
        <translation>恢复到已保存</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>撤销</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>重做</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Z</source>
        <translation></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
    <message>
        <source>Find...</source>
        <translation>查找…</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation></translation>
    </message>
    <message>
        <source>Find Again</source>
        <translation>查找下一个</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation></translation>
    </message>
    <message>
        <source>Replace...</source>
        <translation>替换…</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation></translation>
    </message>
    <message>
        <source>Copy to Find</source>
        <translation>复制到查找</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation></translation>
    </message>
    <message>
        <source>Copy to Replace</source>
        <translation>复制到替换</translation>
    </message>
    <message>
        <source>Ctrl+Shift+E</source>
        <translation></translation>
    </message>
    <message>
        <source>Go to Line...</source>
        <translation>跳至行…</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation></translation>
    </message>
    <message>
        <source>Find Selection</source>
        <translation>查找已选择</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation></translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>选择所有</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <source>Font...</source>
        <translation>字体…</translation>
    </message>
    <message>
        <source>Indent</source>
        <translation>缩进</translation>
    </message>
    <message>
        <source>Ctrl+]</source>
        <translation></translation>
    </message>
    <message>
        <source>Unindent</source>
        <translation>取消缩进</translation>
    </message>
    <message>
        <source>Ctrl+[</source>
        <translation></translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>注释掉</translation>
    </message>
    <message>
        <source>Ctrl+Shift+]</source>
        <translation></translation>
    </message>
    <message>
        <source>Uncomment</source>
        <translation>取消注释</translation>
    </message>
    <message>
        <source>Ctrl+Shift+[</source>
        <translation></translation>
    </message>
    <message>
        <source>Wrap Lines</source>
        <translation>自动换行</translation>
    </message>
    <message>
        <source>About TeXworks...</source>
        <translation>关于 TeXworks...</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>层叠</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>平铺</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>首选项...</translation>
    </message>
    <message>
        <source>Go to Preview</source>
        <translation>转至预览</translation>
    </message>
    <message>
        <source>Ctrl+&apos;</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+\</source>
        <translation></translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>从模板新建...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Show Selection</source>
        <translation>显示已选择</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation></translation>
    </message>
    <message>
        <source>ALL UPPERCASE</source>
        <translation>全转换成大写</translation>
    </message>
    <message>
        <source>all lowercase</source>
        <translation>全转换成小写</translation>
    </message>
    <message>
        <source>Balance Delimiters</source>
        <translation>平衡分隔符</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation></translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>TeXworks 主页</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>发送 Email 至邮件列表</translation>
    </message>
    <message>
        <source>Side by Side</source>
        <translation>并排</translation>
    </message>
    <message>
        <source>Place on Left</source>
        <translation>置于左侧</translation>
    </message>
    <message>
        <source>Place on Right</source>
        <translation>置于右侧</translation>
    </message>
    <message>
        <source>Replace Again</source>
        <translation>替换下一个</translation>
    </message>
    <message>
        <source>Ctrl+Shift+R</source>
        <translation></translation>
    </message>
    <message>
        <source>Remove Aux Files...</source>
        <translation>删除辅助文件...</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>退出 TeXworks</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <source>Toggle Case</source>
        <translation>改变大小写</translation>
    </message>
    <message>
        <source>Hard Wrap...</source>
        <translation>硬换行...</translation>
    </message>
    <message>
        <source>The program &quot;%1&quot; was not found.</source>
        <translation>程序“%1”无法找到。</translation>
    </message>
    <message>
        <source>Searched in directories:</source>
        <translation>在目录中搜索：</translation>
    </message>
    <message>
        <source>Line Numbers</source>
        <translation>行号</translation>
    </message>
    <message>
        <source>Process interrupted by user</source>
        <translation>用户中断了进程</translation>
    </message>
    <message>
        <source>Typeset</source>
        <comment>menu title</comment>
        <translation>排版</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <comment>action</comment>
        <translation></translation>
    </message>
    <message>
        <source>Console output</source>
        <translation>控制台输出</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>脚本</translation>
    </message>
    <message>
        <source>Show Scripts Folder</source>
        <translation>显示脚本文件夹</translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation>管理脚本</translation>
    </message>
    <message>
        <source>Cannot read file &quot;%1&quot;:
%2</source>
        <translation>无法读入文件“%1”：
%2</translation>
    </message>
    <message>
        <source>Cannot write file &quot;%1&quot;:
%2</source>
        <translation>无法写入文件“%1”：
%2</translation>
    </message>
    <message>
        <source>Abort typesetting</source>
        <translation>中止排版</translation>
    </message>
    <message>
        <source>Auto-Follow Focus</source>
        <translation>自动跟踪焦点</translation>
    </message>
    <message>
        <source>Scripting TeXworks</source>
        <translation>TeXworks 脚本</translation>
    </message>
    <message>
        <source>Reload Script List</source>
        <translation>重载脚本列表</translation>
    </message>
    <message>
        <source>About Scripts...</source>
        <translation>关于脚本...</translation>
    </message>
    <message>
        <source>Apply to Selection</source>
        <translation>应用至选择内容</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation>保存全部</translation>
    </message>
    <message>
        <source>Ctrl+Alt+S</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <comment>shortcut: Don&apos;t Save</comment>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <comment>shortcut: Revert</comment>
        <translation></translation>
    </message>
    <message>
        <source>File &quot;%1&quot; loaded</source>
        <translation>文件“%1”已加载</translation>
    </message>
    <message>
        <source>Error writing file</source>
        <translation>写文件错误</translation>
    </message>
    <message>
        <source>An error may have occurred while saving the file. You might like to save a copy in a different location.</source>
        <translation>保存文件时出错。您可以换个位置保存文件。</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; saved</source>
        <translation>文件“%1”已保存</translation>
    </message>
    <message>
        <source>%1 is constantly being modified by another program.

Please use &quot;File &gt; Revert to Saved&quot; manually when the external process has finished.</source>
        <translation>%1 经常被其它程序修改。
请在外部程序完成后，手动执行“文件-&gt;恢复到已保存”命令重新载入。</translation>
    </message>
    <message>
        <source>Settings and Resources...</source>
        <translation>TeXworks 配置与资源 ...</translation>
    </message>
    <message>
        <source>Reload using selected encoding</source>
        <extracomment>Item in the encoding popup menu</extracomment>
        <translation>使用所选编码重载文档</translation>
    </message>
    <message>
        <source>Unsaved changes</source>
        <translation>未保存的改动</translation>
    </message>
    <message>
        <source>The file you are trying to reload has unsaved changes.

Do you want to discard your current changes, and reload the file from disk with the encoding %1?</source>
        <translation>试图重载的文件有改动未保存。

您想放弃这些改动并重新使用编码 %1 载入磁盘上的文件吗？</translation>
    </message>
    <message>
        <source>Reloads the current file with the encoding selected from this menu.

The selected encoding replaces the default one and overrides all &quot;%!TEX encoding&quot; lines.</source>
        <extracomment>Tooltip for &quot;Reload using selected encoding&quot;</extracomment>
        <translation>根据本菜单中所选编码重新载入当前文件。
所选编码会替代默认编码格式并会忽略所有“%!TEX-encoding”行。</translation>
    </message>
    <message>
        <source>Clear Recent Files</source>
        <translation>清除近期文件</translation>
    </message>
    <message>
        <source>Abort typesetting?</source>
        <translation>终止排版？</translation>
    </message>
    <message>
        <source>A typesetting process is still running and must be stopped before closing this window.
Do you want to stop it now?</source>
        <translation>排版进程仍在运行，关闭此窗口前必须停止。你想停止它吗？</translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt; or &lt;a href=&quot;http://miktex.org/&quot;&gt;MiKTeX&lt;/a&gt; installed on your system to typeset your document.</source>
        <translation>你需要安装一份&lt;b&gt;TeX 发行版&lt;/b&gt;来排版你的文档，如&lt;a href=&quot;http://www.tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt;或&lt;a href=&quot;http://miktex.org/&quot;&gt;MiKTeX&lt;/a&gt;。</translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://www.tug.org/mactex/&quot;&gt;MacTeX&lt;/a&gt; installed on your system to typeset your document.</source>
        <translation>你需要安装一份&lt;b&gt;TeX 发行版&lt;/b&gt;来排版你的文档，如&lt;a href=&quot;http://www.tug.org/mactex/&quot;&gt;MacTeX&lt;/a&gt;。</translation>
    </message>
    <message>
        <source>You need a &lt;b&gt;TeX distribution&lt;/b&gt; like &lt;a href=&quot;http://tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt; installed on your system to typeset your document. On most systems such a TeX distribution is available as prebuilt package.</source>
        <translation>你需要安装一份&lt;b&gt;TeX 发行版&lt;/b&gt;来排版你的文档，如&lt;a href=&quot;http://www.tug.org/texlive/&quot;&gt;TeX Live&lt;/a&gt;，大多数系统都可以获得一份现成的此类 TeX 发行版。</translation>
    </message>
    <message>
        <source>When a TeX distribution is installed you may need to tell TeXworks where to find it in Edit -&gt; Preferences -&gt; Typesetting.</source>
        <translation>在已安装 TeX 发行版的情况下，你可以在【编辑】-&gt;【首选项】-&gt;【排版】中进行设置通知 TeXworks 其路径。</translation>
    </message>
    <message>
        <source>Check the configuration of the %1 tool and the path settings in the Preferences dialog.</source>
        <translation>检查首选项对话框工具 %1 的配置和路径设置。</translation>
    </message>
    <message>
        <source>Hide Console Output</source>
        <translation>隐藏控制台输出</translation>
    </message>
    <message>
        <source>Layout Problem</source>
        <translation>排版问题</translation>
    </message>
    <message>
        <source>A problem occured while laying out the loaded document in the editor. This is caused by an issue in the underlying Qt framework and can cause TeXworks to crash under certain circumstances. The symptoms of this problem are hidden or overlapping lines. To work around this, please try one of the following:
 -) Turn syntax highlighting off and on
 -) Turn line numbers off and on
 -) Resize the window

We are sorry for the inconvenience.</source>
        <translation>编辑器显示当前文档时出现问题，表现为行隐藏和行重叠。这是由于底层Qt框架的问题，在某些情况下会导致TeXworks崩溃。请尝试以下措施以解决这一问题：
-&gt; 关闭语法高亮显示并重新打开
-&gt; 关闭行号并重新打开
-&gt; 调整窗口大小

不便之处请谅解。</translation>
    </message>
    <message>
        <source>Show Console Output</source>
        <translation>显示控制台输出</translation>
    </message>
    <message>
        <source>Write UTF-8 byte order mark</source>
        <translation>写入 UTF-8 字节顺序标记(BOM)</translation>
    </message>
</context>
<context>
    <name>TeXHighlighter</name>
    <message>
        <source>default</source>
        <translation>默认</translation>
    </message>
</context>
<context>
    <name>TemplateDialog</name>
    <message>
        <source>New File using Template</source>
        <translation>从模板创建新文档</translation>
    </message>
    <message>
        <source>Choose template for the new document:</source>
        <translation>为新文档选择模板：</translation>
    </message>
</context>
<context>
    <name>ToolConfig</name>
    <message>
        <source>NewArgument</source>
        <translation>新参数</translation>
    </message>
    <message>
        <source>Select program file</source>
        <translation>选择程序文件</translation>
    </message>
    <message>
        <source>Invalid program</source>
        <translation>无效程序</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; is not executable!</source>
        <translation>“%1”不是可执行文件!</translation>
    </message>
</context>
<context>
    <name>ToolConfigDialog</name>
    <message>
        <source>Tool Configuration</source>
        <translation>工具配置</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>名称:</translation>
    </message>
    <message>
        <source>Program:</source>
        <translation>程序：</translation>
    </message>
    <message>
        <source>Arguments:</source>
        <translation>参数：</translation>
    </message>
    <message>
        <source>View PDF after running</source>
        <translation>运行后查看 PDF 文件</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>浏览...</translation>
    </message>
</context>
</TS>
